@@ -3,7 +3,6 @@
 // license that can be found in the LICENSE file.
 
 //go:build !windows
-// +build !windows
 
 package docker
 
@@ -13,10 +12,12 @@ import (
 	"net/http/httptest"
 	"os"
 	"reflect"
-	"sort"
+	"slices"
 	"sync"
 	"testing"
 	"time"
+
+	"github.com/fsouza/go-dockerclient/internal/testutils"
 )
 
 func TestClientDoConcurrentStress(t *testing.T) {
@@ -29,7 +30,7 @@ func TestClientDoConcurrentStress(t *testing.T) {
 		mu.Unlock()
 	})
 	var nativeSrvs []*httptest.Server
-	for i := 0; i < 3; i++ {
+	for range 3 {
 		srv, cleanup, err := newNativeServer(handler)
 		if err != nil {
 			t.Fatal(err)
@@ -55,6 +56,8 @@ func TestClientDoConcurrentStress(t *testing.T) {
 	for _, tt := range tests {
 		tt := tt
 		t.Run(tt.testCase, func(t *testing.T) {
+			_, serverCert := testutils.GenCertificate(t)
+
 			reqs = nil
 			var client *Client
 			var err error
@@ -66,11 +69,11 @@ func TestClientDoConcurrentStress(t *testing.T) {
 			}
 			defer tt.srv.Close()
 			if tt.withTLSClient {
-				certPEMBlock, certErr := os.ReadFile("testing/data/cert.pem")
+				certPEMBlock, certErr := os.ReadFile(serverCert.CertPath)
 				if certErr != nil {
 					t.Fatal(certErr)
 				}
-				keyPEMBlock, certErr := os.ReadFile("testing/data/key.pem")
+				keyPEMBlock, certErr := os.ReadFile(serverCert.KeyPath)
 				if certErr != nil {
 					t.Fatal(certErr)
 				}
@@ -89,7 +92,7 @@ func TestClientDoConcurrentStress(t *testing.T) {
 			var paths []string
 			errsCh := make(chan error, 3*n)
 			waiters := make(chan CloseWaiter, n)
-			for i := 0; i < n; i++ {
+			for i := range n {
 				path := fmt.Sprintf("/%05d", i)
 				paths = append(paths, http.MethodGet+path)
 				paths = append(paths, http.MethodPost+path)
@@ -127,8 +130,8 @@ func TestClientDoConcurrentStress(t *testing.T) {
 			for _, r := range reqs {
 				reqPaths = append(reqPaths, r.Method+r.URL.Path)
 			}
-			sort.Strings(paths)
-			sort.Strings(reqPaths)
+			slices.Sort(paths)
+			slices.Sort(reqPaths)
 			if !reflect.DeepEqual(reqPaths, paths) {
 				t.Fatalf("expected server request paths to equal %v, got: %v", paths, reqPaths)
 			}
